summaryrefslogtreecommitdiffstats
path: root/kdm/kfrontend/themer/kdmitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdm/kfrontend/themer/kdmitem.h')
-rw-r--r--kdm/kfrontend/themer/kdmitem.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdm/kfrontend/themer/kdmitem.h b/kdm/kfrontend/themer/kdmitem.h
index ca6bd3435..c76222914 100644
--- a/kdm/kfrontend/themer/kdmitem.h
+++ b/kdm/kfrontend/themer/kdmitem.h
@@ -120,7 +120,7 @@ public:
void mouseEvent( int x, int y, bool pressed = false, bool released = false );
/**
* Similar to tqsizeHint(..), this returns the area of the item
* given the @p parentGeometry. The default implementation
* takes into account geometric constraints and layoutings.
* @param parentGeometry the geometry of the caller item or a
@@ -181,7 +181,7 @@ protected:
* @return (-1,-1) if no size can be determined (so it should
* default to parent's size).
*/
- virtual TQSize tqsizeHint();
+ virtual TQSize sizeHint();
/**
* Low level graphical function to paint the item.
@@ -120,7 +120,7 @@ public:
void mouseEvent( int x, int y, bool pressed = false, bool released = false );
/**
- * Similar to tqsizeHint(..), this returns the area of the item
+ * Similar to sizeHint(..), this returns the area of the item
* given the @p parentGeometry. The default implementation
* takes into account geometric constraints and layoutings.